Learn R Programming

pvrank (version 1.1)

Dizytwin: Latitude and dizygotic twinning rates

Description

Age-standardized dizygotic twinning rates correlate positively and significantly with latitude.

Usage

data(Dizytwin)

Arguments

Format

A data frame with 19 observations on the following two variables.
Latitude
Geographical latitude in Europe.
DZT_Rate
Dizygotic twinning rates across the countries.

James, W. H. (1985). "Dizygotic twinning, birth weight and latitude". Annals of Human Biology,12, 441--447.

Details

In Europe, both mean birth weight and age-standardized dizygotic twinning rates correlate positively and significantly with latitude. It seems possible that these two sorts of correlation have explanations in common via pituitary action.

Examples

Run this code
	data(Dizytwin)
	head(Dizytwin)

Run the code above in your browser using DataLab